Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
mcpgateway/__init__.py | 8 | 0 | 0 | 0 | 0 | 100%
mcpgateway/admin.py | 414 | 69 | 0 | 44 | 17 | 79%
mcpgateway/alembic/env.py | 24 | 5 | 0 | 4 | 2 | 75%
mcpgateway/alembic/versions/b77ca9d2de7e_uuid_pk_and_slug_refactor.py | 175 | 161 | 0 | 22 | 0 | 7%
mcpgateway/alembic/versions/e4fc04d1a442_add_annotations_to_tables.py | 21 | 12 | 0 | 4 | 0 | 36%
mcpgateway/alembic/versions/e75490e949b1_add_improved_status_to_tables.py | 17 | 8 | 0 | 0 | 0 | 53%
mcpgateway/bootstrap_db.py | 22 | 3 | 2 | 2 | 1 | 83%
mcpgateway/cache/__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
mcpgateway/cache/resource_cache.py | 56 | 4 | 0 | 10 | 2 | 91%
mcpgateway/cache/session_registry.py | 417 | 186 | 0 | 140 | 11 | 58%
mcpgateway/cli.py | 29 | 0 | 2 | 10 | 1 | 97%
mcpgateway/config.py | 194 | 13 | 0 | 36 | 7 | 91%
mcpgateway/db.py | 395 | 84 | 3 | 38 | 8 | 74%
mcpgateway/federation/__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
mcpgateway/federation/discovery.py | 176 | 93 | 0 | 40 | 6 | 44%
mcpgateway/federation/forward.py | 122 | 50 | 0 | 38 | 9 | 53%
mcpgateway/handlers/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
mcpgateway/handlers/sampling.py | 87 | 3 | 0 | 44 | 4 | 95%
mcpgateway/main.py | 732 | 207 | 0 | 86 | 26 | 70%
mcpgateway/models.py | 206 | 1 | 0 | 2 | 1 | 99%
mcpgateway/schemas.py | 476 | 89 | 0 | 76 | 12 | 74%
mcpgateway/services/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
mcpgateway/services/completion_service.py | 70 | 6 | 0 | 26 | 2 | 92%
mcpgateway/services/gateway_service.py | 420 | 214 | 0 | 130 | 21 | 44%
mcpgateway/services/logging_service.py | 55 | 5 | 0 | 10 | 0 | 92%
mcpgateway/services/prompt_service.py | 270 | 86 | 0 | 72 | 18 | 63%
mcpgateway/services/resource_service.py | 302 | 25 | 0 | 84 | 10 | 89%
mcpgateway/services/root_service.py | 69 | 6 | 0 | 10 | 0 | 92%
mcpgateway/services/server_service.py | 234 | 66 | 0 | 72 | 23 | 70%
mcpgateway/services/tool_service.py | 341 | 36 | 0 | 92 | 2 | 91%
mcpgateway/translate.py | 198 | 28 | 5 | 40 | 7 | 83%
mcpgateway/transports/__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
mcpgateway/transports/base.py | 13 | 0 | 0 | 0 | 0 | 100%
mcpgateway/transports/sse_transport.py | 77 | 2 | 0 | 10 | 2 | 95%
mcpgateway/transports/stdio_transport.py | 55 | 0 | 0 | 8 | 0 | 100%
mcpgateway/transports/streamablehttp_transport.py | 142 | 5 | 0 | 26 | 3 | 95%
mcpgateway/transports/websocket_transport.py | 80 | 1 | 0 | 18 | 2 | 97%
mcpgateway/utils/create_jwt_token.py | 54 | 0 | 27 | 10 | 0 | 100%
mcpgateway/utils/create_slug.py | 12 | 0 | 0 | 2 | 0 | 100%
mcpgateway/utils/db_isready.py | 76 | 0 | 45 | 12 | 1 | 99%
mcpgateway/utils/redis_isready.py | 44 | 6 | 40 | 10 | 1 | 87%
mcpgateway/utils/services_auth.py | 33 | 0 | 0 | 6 | 0 | 100%
mcpgateway/utils/verify_credentials.py | 45 | 0 | 0 | 12 | 0 | 100%
mcpgateway/validation/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
mcpgateway/validation/jsonrpc.py | 58 | 9 | 0 | 34 | 9 | 80%
mcpgateway/version.py | 126 | 24 | 0 | 16 | 4 | 80%
mcpgateway/wrapper.py | 217 | 29 | 11 | 50 | 9 | 86%
Total | 6582 | 1536 | 135 | 1346 | 221 | 74%

No items found using the specified filter.